==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1alpha1PodPresetFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1alpha1PodPresetFluent<A extends V1alpha1PodPresetFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1alpha1PodPresetFluent.MetadataNested<A> withNewMetadata();
    public V1alpha1PodPresetFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1alpha1PodPresetFluent.MetadataNested<A> editMetadata();
    public V1alpha1PodPresetFluent.MetadataNested<A> editOrNewMetadata();
    public V1alpha1PodPresetFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PodPresetSpec getSpec();
    public V1alpha1PodPresetSpec buildSpec();
    public A withSpec(V1alpha1PodPresetSpec spec);
    public Boolean hasSpec();
    public V1alpha1PodPresetFluent.SpecNested<A> withNewSpec();
    public V1alpha1PodPresetFluent.SpecNested<A> withNewSpecLike(V1alpha1PodPresetSpec item);
    public V1alpha1PodPresetFluent.SpecNested<A> editSpec();
    public V1alpha1PodPresetFluent.SpecNested<A> editOrNewSpec();
    public V1alpha1PodPresetFluent.SpecNested<A> editOrNewSpecLike(V1alpha1PodPresetSpec item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1alpha1PodPresetFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1alpha1PodPresetSpecFluent<V1alpha1PodPresetFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1alpha1PodPresetFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1alpha1PodPresetFluent<A extends V1alpha1PodPresetFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1alpha1PodPresetFluent.MetadataNested<A> withNewMetadata();
    public V1alpha1PodPresetFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1alpha1PodPresetFluent.MetadataNested<A> editMetadata();
    public V1alpha1PodPresetFluent.MetadataNested<A> editOrNewMetadata();
    public V1alpha1PodPresetFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PodPresetSpec getSpec();
    public V1alpha1PodPresetSpec buildSpec();
    public A withSpec(V1alpha1PodPresetSpec spec);
    public Boolean hasSpec();
    public V1alpha1PodPresetFluent.SpecNested<A> withNewSpec();
    public V1alpha1PodPresetFluent.SpecNested<A> withNewSpecLike(V1alpha1PodPresetSpec item);
    public V1alpha1PodPresetFluent.SpecNested<A> editSpec();
    public V1alpha1PodPresetFluent.SpecNested<A> editOrNewSpec();
    public V1alpha1PodPresetFluent.SpecNested<A> editOrNewSpecLike(V1alpha1PodPresetSpec item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1alpha1PodPresetFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1alpha1PodPresetSpecFluent<V1alpha1PodPresetFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}
